/**
   @file main.c
   @brief Basic example of peripheral access
   
   @author Angel Perles http://armpower.blogs.upv.es
   @date 2015/06/15
*/

#include <stm32f4xx.h>

void retardo(uint32_t cuenta);
void LED_Init(void);
void LED_On(void);
void LED_Off(void);

/*** programa principal ******************************************************/
int main (void) 
{
   
   LED_Init();

   while (1) {
        LED_On();
        retardo(5000000);
        LED_Off();
        retardo(5000000);
   }
      
   //return(0);
}


/*****************************************************************************/
/**
  * @brief  Configure the pin associated to the blue LED, PD15
  * @param  nothing
  * @retval nothing
  */
void LED_Init(void) 
{
   GPIO_InitTypeDef  GPIO_InitStructure;  // estructura donde se pone la configuración deseada

   RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE); // darle reloj al periférico, AHORA VIVE!
    
   GPIO_StructInit(&GPIO_InitStructure);   // establecer valores por defecto

   /* dar los detalles del puerto/pin */
   GPIO_InitStructure.GPIO_Pin   = GPIO_Pin_15;        // pin que desamos configurar
   GPIO_InitStructure.GPIO_Mode  = GPIO_Mode_OUT;      // lo vamos a usar como salida
   GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;      // queremos que sea push-pull
   GPIO_InitStructure.GPIO_Speed = GPIO_Speed_25MHz;   // frecuencia máxima para el puerto
   GPIO_InitStructure.GPIO_PuPd  = GPIO_PuPd_NOPULL;   // desactivar los pull-up, no hacen falta
   
   GPIO_Init(GPIOD, &GPIO_InitStructure);              // hacer efectiva configuración puerto
}


/*****************************************************************************/
/**
  * @brief  Turn on the LED
  * @param  nothing
  * @retval nothing
  */
void LED_On(void) 
{
    GPIO_SetBits(GPIOD, GPIO_Pin_15);     // poner a "1" la línea PD15
}


/*****************************************************************************/
/**
  * @brief  Turn off the LED
  * @param  nothing
  * @retval noting
  */
void LED_Off(void) 
{
    GPIO_ResetBits(GPIOD, GPIO_Pin_15);     // poner a "0" la línea PD15
}

/*****************************************************************************/
/**
  * @brief  Funcion de retardo básica
  * @param  cuenta:el retardo a ojo
  * @retval Nada
  */
void retardo(uint32_t nCount)
{
  while(nCount--)
  {
  }
}
